@@ -43,13 +43,13 @@ intersphinx_mapping = {'http://docs.python.org/': None}
 
 rst_epilog = '''
 .. |djvu3ref| replace:: Lizardtech DjVu Reference
-.. _djvu3ref: http://www.lizardtech.com/files/doc/techinfo/DjVu3Spec.djvu
+.. _djvu3ref: http://djvu.org/docs/DjVu3Spec.djvu
 
 .. |djvused| replace:: djvused manual
 .. _djvused: http://djvu.sourceforge.net/doc/man/djvused.html
 
 .. |djvuext| replace:: Actual and proposed changes to the DjVu format
-.. _djvuext: http://djvu.cvs.sourceforge.net/djvu/djvulibre-3.5/doc/djvuchanges.txt?revision=1.13
+.. _djvuext: http://djvu.git.sourceforge.net/git/gitweb.cgi?p=djvu/djvulibre.git;a=blob;f=doc/djvuchanges.txt;hb=refs/tags/release.3.5.23
 '''
 
 # vim:ts=4 sw=4 et
